summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms/kexiformscrollview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/forms/kexiformscrollview.h')
-rw-r--r--kexi/plugins/forms/kexiformscrollview.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/kexi/plugins/forms/kexiformscrollview.h b/kexi/plugins/forms/kexiformscrollview.h
index 12315761..cf2731d1 100644
--- a/kexi/plugins/forms/kexiformscrollview.h
+++ b/kexi/plugins/forms/kexiformscrollview.h
@@ -47,10 +47,11 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
public KexiFormEventHandler
{
Q_OBJECT
+ TQ_OBJECT
KEXI_DATAAWAREOBJECTINTERFACE
public:
- KexiFormScrollView(QWidget *parent, bool preview);
+ KexiFormScrollView(TQWidget *tqparent, bool preview);
virtual ~KexiFormScrollView();
void setForm(KFormDesigner::Form *form) { m_form = form; }
@@ -78,7 +79,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
dbFormWidget()->orderedDataAwareWidgets()->at( col ));
if (!item)
return -1;
- KexiFormDataItemInterfaceToIntMap::ConstIterator it(m_fieldNumbersForDataItems.find( item ));
+ KexiFormDataItemInterfaceToIntMap::ConstIterator it(m_fieldNumbersForDataItems.tqfind( item ));
return it!=m_fieldNumbersForDataItems.constEnd() ? (int)it.data() : -1;
}
@@ -93,7 +94,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
virtual int lastVisibleRow() const;
/*! \return vertical scrollbar. Implemented for KexiDataAwareObjectInterface. */
- virtual QScrollBar* verticalScrollBar() const { return KexiScrollView::verticalScrollBar(); }
+ virtual TQScrollBar* verticalScrollBar() const { return KexiScrollView::verticalScrollBar(); }
public slots:
/*! Reimplemented to update resize policy. */
@@ -141,7 +142,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
signals:
virtual void itemChanged(KexiTableItem *, int row, int col);
- virtual void itemChanged(KexiTableItem *, int row, int col, QVariant oldValue);
+ virtual void itemChanged(KexiTableItem *, int row, int col, TQVariant oldValue);
virtual void itemDeleteRequest(KexiTableItem *, int row, int col);
virtual void currentItemDeleteRequest();
virtual void newItemAppendedForAfterDeletingInSpreadSheetMode(); //!< does nothing
@@ -161,19 +162,19 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
virtual void slotRowRepaintRequested(KexiTableItem& item);
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
- virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint)
- { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, repaint); }
+ virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint)
+ { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, tqrepaint); }
- //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
virtual void slotRowDeleted() { KexiDataAwareObjectInterface::slotRowDeleted(); }
- //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool repaint);
+ //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint);
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint);
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint);
- virtual void slotRowsDeleted( const QValueList<int> & );
+ virtual void slotRowsDeleted( const TQValueList<int> & );
virtual void slotDataDestroying() { KexiDataAwareObjectInterface::slotDataDestroying(); }
@@ -192,11 +193,11 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
protected:
//! Implementation for KexiDataAwareObjectInterface
- virtual void clearColumnsInternal(bool repaint);
+ virtual void clearColumnsInternal(bool tqrepaint);
//! Implementation for KexiDataAwareObjectInterface
- virtual void addHeaderColumn(const QString& caption, const QString& description,
- const QIconSet& icon, int width);
+ virtual void addHeaderColumn(const TQString& caption, const TQString& description,
+ const TQIconSet& icon, int width);
//! Implementation for KexiDataAwareObjectInterface
virtual int currentLocalSortingOrder() const;
@@ -214,7 +215,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
virtual void updateGUIAfterSorting();
//! Implementation for KexiDataAwareObjectInterface
- virtual void createEditor(int row, int col, const QString& addText = QString::null,
+ virtual void createEditor(int row, int col, const TQString& addText = TQString(),
bool removeOld = false);
//! Implementation for KexiDataAwareObjectInterface
@@ -240,12 +241,12 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
/*! Implementation for KexiDataAwareObjectInterface
Implementation for KexiDataAwareObjectInterface
- Updates widget's contents size e.g. using QScrollView::resizeContents(). */
+ Updates widget's contents size e.g. using TQScrollView::resizeContents(). */
virtual void updateWidgetContentsSize();
/*! Implementation for KexiDataAwareObjectInterface
Updates scrollbars of the widget.
- QScrollView::updateScrollbars() will be usually called here. */
+ TQScrollView::updateScrollbars() will be usually called here. */
virtual void updateWidgetScrollBars();
KexiDBForm* dbFormWidget() const;
@@ -281,7 +282,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
/*! @internal
Used to invoke copy/paste/cut etc. actions at the focused widget's level. */
- void handleDataWidgetAction(const QString& actionName);
+ void handleDataWidgetAction(const TQString& actionName);
/*! @internal */
bool shouldDisplayDefaultValueForItem(KexiFormDataItemInterface* itemIface) const;